==> periscope_1.0.0.tar.gz: periscope/tests/testthat/_snaps/downloadable_plot.md <==
# downloadablePlotUI btn_overlap=true btn_halign=left btn_valign=bottom

    [[1]]
    <div id="myid-dplotOutputID" class="shiny-plot-output" style="width:80%;height:300px;"></div>
    
    [[2]]
    <span id="myid-dplotButtonDiv" class="periscope-downloadable-plot-button" style="display:none; padding: 5px;float:left;top: -50px">
      <span>
        <a id="myid-dplotButtonID-png" class="btn btn-default shiny-download-link periscope-download-btn" href="" target="_blank" download>
          <i class="fa fa-download" role="presentation" aria-label="download icon"></i>
        </a>
        <script>$(document).ready(function() {setTimeout(function() {shinyBS.addTooltip('myid-dplotButtonID-png', 'tooltip', {'placement': 'top', 'trigger': 'hover', 'title': 'myhovertext'})}, 500)});</script>
      </span>
    </span>
    

# downloadablePlotUI btn_overlap=false btn_halign=center btn_valign=top

    [[1]]
    <span id="myid-dplotButtonDiv" class="periscope-downloadable-plot-button" style="display:none; padding: 5px;float:none;margin-left:45%;top: -5px">
      <span>
        <a id="myid-dplotButtonID-png" class="btn btn-default shiny-download-link periscope-download-btn" href="" target="_blank" download>
          <i class="fa fa-download" role="presentation" aria-label="download icon"></i>
        </a>
        <script>$(document).ready(function() {setTimeout(function() {shinyBS.addTooltip('myid-dplotButtonID-png', 'tooltip', {'placement': 'top', 'trigger': 'hover', 'title': 'myhovertext'})}, 500)});</script>
      </span>
    </span>
    
    [[2]]
    <div id="myid-dplotOutputID" class="shiny-plot-output" style="width:80%;height:300px;"></div>

==> periscope_1.0.3.tar.gz: periscope/tests/testthat/_snaps/downloadable_plot.md <==
# downloadablePlotUI btn_overlap=true btn_halign=left btn_valign=bottom

    [[1]]
    <div class="shiny-plot-output html-fill-item" id="myid-dplotOutputID" style="width:80%;height:300px;"></div>
    
    [[2]]
    <span id="myid-dplotButtonDiv" class="periscope-downloadable-plot-button" style="display:none; padding: 5px;float:left;top: -50px">
      <span>
        <a id="myid-dplotButtonID-png" class="btn btn-default shiny-download-link periscope-download-btn" href="" target="_blank" download>
          <i class="fas fa-download" role="presentation" aria-label="download icon"></i>
        </a>
        <script>$(document).ready(function() {setTimeout(function() {shinyBS.addTooltip('myid-dplotButtonID-png', 'tooltip', {'placement': 'top', 'trigger': 'hover', 'title': 'myhovertext'})}, 500)});</script>
      </span>
    </span>
    

# downloadablePlotUI btn_overlap=false btn_halign=center btn_valign=top

    [[1]]
    <span id="myid-dplotButtonDiv" class="periscope-downloadable-plot-button" style="display:none; padding: 5px;float:none;margin-left:45%;top: -5px">
      <span>
        <a id="myid-dplotButtonID-png" class="btn btn-default shiny-download-link periscope-download-btn" href="" target="_blank" download>
          <i class="fas fa-download" role="presentation" aria-label="download icon"></i>
        </a>
        <script>$(document).ready(function() {setTimeout(function() {shinyBS.addTooltip('myid-dplotButtonID-png', 'tooltip', {'placement': 'top', 'trigger': 'hover', 'title': 'myhovertext'})}, 500)});</script>
      </span>
    </span>
    
    [[2]]
    <div class="shiny-plot-output html-fill-item" id="myid-dplotOutputID" style="width:80%;height:300px;"></div>
